==> opendbl-r77-0.72.tar: opendbl-installer/opendbl.sh <==
#!/bin/bash
type="$1"
op="$2"

is_fw_module=$($CPDIR/bin/cpprod_util FwIsFirewallModule)
#is_fw_module=1

function remove_existing_sam_rules {
        fw samp get | awk '/comment=OPENDBL_'$type'_block/{sub("uid=","",$2);print "del "$2}' | fw samp batch 1>/dev/null 2>&1
        fw samp add -t 2 quota flush true 1>/dev/null 2>&1
}

function print_help {
                echo ""
                echo "This script is intended to run on a Check Point Firewall"
                echo "Proceed at your own risk"
                echo ""
                echo "Usage:"
                echo "  opendbl.sh <listname> <option>"
                echo ""
                echo "Lists:"
                echo "  etknown		Emerging threats known compromised hosts"
                echo "  tor             	TOR exit nodes"
                echo "  bruteforce      	Bruteforceblocker (danger.rulez.sk)"
                echo "  talos       		Cisco Talos known malicious network threats."
                echo "  blocklistde     	Blocklist.de (all known attackers last 48 hours)"
                echo "  dshield	     	DShield.org recommended block list."
                echo ""
                echo "Options:"
                echo "  on			Enables list"
                echo "  off			Disables list and clears block tables"
                echo "  stat			Prints status of list"
                echo ""
                echo ""
}

case $type in etknown|tor|bruteforce|talos|blocklistde|dshield)

# Run only on GAIA gateways
if [[ "$is_fw_module" -eq 1 && /etc/appliance_config.xml ]]; then

        case "$op" in

                on)
                $CPDIR/bin/cpd_sched_config add OPENDBL_$type -c "$CPDIR/bin/ip-opendbl-$type.sh" -e 43200 -r -s
                echo "$type blocking mechanism is ON"
                ;;

                off)
                $CPDIR/bin/cpd_sched_config delete OPENDBL_$type -r
                remove_existing_sam_rules
                echo "$type blocking mechanism is OFF"
                ;;

                stat)
                cpd_sched_config print | awk 'BEGIN{res="OFF"}/Task/{flag=0}/OPENDBL_'$type'/{flag=1}/Active: true/{if(flag)res="ON"}END{print "'$type' list status is "res}'

               ;;

                *)
                print_help
        esac

else

print_help

fi

;;
*)
print_help
;;
esac

==> opendbl-r80-0.4.tar: opendbl-installer/opendbl.sh <==
#!/bin/bash
type="$1"
op="$2"

is_fw_module=$($CPDIR/bin/cpprod_util FwIsFirewallModule)
#is_fw_module=1

function remove_existing_sam_rules {
	dynamic_objects -do openDBL_$type
}

function print_help {
                echo ""
                echo "This script is intended to run on a Check Point Firewall"
                echo "Proceed at your own risk"
                echo ""
                echo "Usage:"
                echo "  opendbl.sh <listname> <option>"
                echo ""
                echo "Lists:"
                echo "  etknown		Emerging threats known compromised hosts"
                echo "  tor             	TOR exit nodes"
                echo "  bruteforce      	Bruteforceblocker (danger.rulez.sk)"
                echo "  talos       		Cisco Talos known malicious network threats."
                echo "  blocklistde     	Blocklist.de (all known attackers last 48 hours)"
                echo "  malware     		malwaredomainlist.com"
                echo "  sslblock     		SSLBL 30day blocklist"
                echo "  zeus     		abuse.ch zeus tracker"
                echo ""
                echo "Options:"
                echo "  on			Enables list"
                echo "  off			Disables list and clears block tables"
                echo "  stat			Prints status of list"
                echo ""
                echo ""
}

case $type in etknown|tor|bruteforce|talos|blocklistde|malware|sslblock|zeus)

# Run only on GAIA gateways
if [[ "$is_fw_module" -eq 1 && /etc/appliance_config.xml ]]; then

        case "$op" in

                on)
                $CPDIR/bin/cpd_sched_config add openDBL_$type -c "$CPDIR/bin/ip-opendbl-$type.sh" -e 43200 -r -s
                echo "Automatic updates of $type is ON"
                ;;

                off)
                $CPDIR/bin/cpd_sched_config delete openDBL_$type -r
                remove_existing_sam_rules
                echo "Automatic updates of $type is OFF"
                ;;

                stat)
                cpd_sched_config print | awk 'BEGIN{res="OFF"}/Task/{flag=0}/OPENDBL_'$type'/{flag=1}/Active: true/{if(flag)res="ON"}END{print "'$type' list status is "res}'

               ;;

                *)
                print_help
        esac

else

print_help

fi

;;
*)
print_help
;;
esac
